@@ -2,33 +2,21 @@ plotTimeSeries <-
 function(mast, set, signal=c("v.avg", "dir.avg", "turb.int"), subset, ...) {
 ### plotting time series of mast data
 		
-	if(is.null(attr(mast, "call"))) stop(paste(substitute(mast), "is no mast object\n"))
-	if(attr(mast, "call")$func!="createMast") stop(paste(substitute(mast), "is no mast object\n"))
+	if(is.null(attr(mast, "call"))) stop(substitute(mast), " is no mast object")
+	if(attr(mast, "call")$func!="createMast") stop(substitute(mast), " is no mast object")
 	num.sets <- length(mast$sets)
 	time.stamp <- mast$time.stamp
-	num.samples <- length(time.stamp)
 	
 	if(missing(set)) set <- 1:num.sets
 	if(!is.numeric(set)) set <- match(set, names(mast$sets))
 	if(any(is.na(set))) stop("'set' not found\n")
 	if(any(set<1) || any(set>num.sets)) stop("'set' not found\n")
-	if(missing(subset)) subset <- c(NA, NA)
-	if((!any(is.character(subset)) && !any(is.na(subset))) || length(subset)!=2) stop("Please specify 'subset' as vector of start and end time stamp\n")
-	if(is.na(subset[1])) subset[1] <- as.character(time.stamp[1])
-	if(is.na(subset[2])) subset[2] <- as.character(time.stamp[num.samples])
-	start <- strptime(subset[1], "%Y-%m-%d %H:%M:%S")
-	end <- strptime(subset[2], "%Y-%m-%d %H:%M:%S")
-	if(is.na(start)) stop("Specified start time stamp in 'subset' not correctly formated\n")
-	if(is.na(end)) stop("Specified end time stamp in 'subset' not correctly formated\n")
-
-	# match start and end date
-	if(start<time.stamp[1] || start>time.stamp[num.samples]) stop("Specified 'start' not in period\n")
-	match.date <- difftime(time.stamp, ISOdatetime(1,1,1,0,0,0), tz="GMT", units="days") - difftime(start, ISOdatetime(1,1,1,0,0,0), tz="GMT", units="days")
-	start <- which(abs(as.numeric(match.date)) == min(abs(as.numeric(match.date))))
 	
-	if(end<time.stamp[1] || end>time.stamp[num.samples]) stop("Specified 'end' not in period\n")
-	match.date <- difftime(time.stamp, ISOdatetime(1,1,1,0,0,0), tz="GMT", units="days") - difftime(end, ISOdatetime(1,1,1,0,0,0), tz="GMT", units="days")
-	end <- which(abs(as.numeric(match.date)) == min(abs(as.numeric(match.date))))
+	# subset
+	if(missing(subset)) subset <- c(NA, NA)
+	start.end <- subsetInt(time.stamp, subset)
+	start <- start.end[1]
+	end <- start.end[2]
 	
 	# get units
 	n.sig <- length(signal)
@@ -96,12 +84,12 @@ function(mast, set, signal=c("v.avg", "dir.avg", "turb.int"), subset, ...) {
 	else {
 		ylab <- NULL
 		for(i in 1:n.sig) {
-			if(signal[i]=="v.avg") ylab <- append(ylab, paste("Wind speed [", units[i], "]", sep=""))
-			else if(signal[i]=="v.max") ylab <- append(ylab, paste("Max wind speed [", units[i], "]", sep=""))
-			else if(signal[i]=="v.min") ylab <- append(ylab, paste("Min wind speed [", units[i], "]", sep=""))
-			else if(signal[i]=="dir.avg") ylab <- append(ylab, paste("Wind direction [", units[i], "]", sep=""))
-			else if(signal[i]=="turb.int") ylab <- append(ylab, paste("Turbulence intensity [", units[i], "]", sep=""))
-			else ylab <- append(ylab, paste(signal[i], " [", units[i], "]", sep=""))
+			if(signal[i]=="v.avg") ylab <- append(ylab, paste0("Wind speed [", units[i], "]"))
+			else if(signal[i]=="v.max") ylab <- append(ylab, paste0("Max wind speed [", units[i], "]"))
+			else if(signal[i]=="v.min") ylab <- append(ylab, paste0("Min wind speed [", units[i], "]"))
+			else if(signal[i]=="dir.avg") ylab <- append(ylab, paste0("Wind direction [", units[i], "]"))
+			else if(signal[i]=="turb.int") ylab <- append(ylab, paste0("Turbulence intensity [", units[i], "]"))
+			else ylab <- append(ylab, paste0(signal[i], " [", units[i], "]"))
 		}
 	}
 	for(i in 1:length(ylab)) if(substr(ylab[i], nchar(ylab[i])-2, nchar(ylab[i]))==" []") ylab[i] <- substr(ylab[i], 1, nchar(ylab[i])-3)
@@ -150,5 +138,5 @@ function(mast, set, signal=c("v.avg", "dir.avg", "turb.int"), subset, ...) {
 	plot(0, type="n", axes=FALSE, xlab="", ylab="")
 	par(mar=c(0,5,0,1))
 	plot(0, type="n", axes=FALSE, xlab="", ylab="")
-	if(legend) legend("center", legend=paste(names, " (", heights, h.unit, ")", sep=""), col=col[set.idx], lty=lty[set.idx], ncol=length(set.idx), bty=bty.leg, cex=cex.leg, text.col=col.leg, x.intersp=x.intersp)
+	if(legend) legend("center", legend=paste0(names, " (", heights, h.unit, ")"), col=col[set.idx], lty=lty[set.idx], ncol=length(set.idx), bty=bty.leg, cex=cex.leg, text.col=col.leg, x.intersp=x.intersp)
 }
