@@ -10,7 +10,7 @@ function(file, ex=FALSE) {
 	}
 	
 	type <- substr(file, nchar(file)-3, nchar(file))
-	if(!any(c(".pow", ".wtg")==type)) stop("Cannot handle file - only WAsP .wtg files and WindPower program .pow files are supported\n")
+	if(!any(c(".pow", ".wtg")==type)) stop("Cannot handle file - only WAsP .wtg files and WindPower program .pow files are supported")
 	
 	r <- NULL
 	if(type==".pow") {
@@ -19,16 +19,14 @@ function(file, ex=FALSE) {
 		if(is.na(cut.out) || is.null(cut.out)) stop("Cannot handle file")
 		v <- seq(1, cut.out, 1)
 		p <- tail(pow, -1)
-		options(warn=-1)
-		if(is.na(as.numeric(tail(p, 1)))) p <- head(p, -1)
-		options(warn=1)
+		suppressWarnings(if(is.na(as.numeric(tail(p, 1)))) p <- head(p, -1))
 		p <- as.numeric(p[5:(cut.out+4),1])
 		desc <- pow[1,1]
 		r <- createPC(v, p, rho=1.225, desc=desc)
 		attr(r, "call") <- list(func="readPC", file=file)
 	} else if(type==".wtg") {
 		wtg <- xmlTreeParse(file, asTree=TRUE)
-		if(is.null(wtg$doc$children$WindTurbineGenerator)) stop("Cannot handle file\n")
+		if(is.null(wtg$doc$children$WindTurbineGenerator)) stop("Cannot handle file")
 		n <- length(wtg$doc$children$WindTurbineGenerator)
 		idx <- 3
 		if(n>4) {
